@@ -1,9 +1,7 @@
 "PlotFreq" <-
-function(path.data,path.mcmc,ipop,iloc,iall,printit=FALSE,path=NULL)
+function(allele.numbers,
+                     path.mcmc,ipop,iloc,iall,printit=FALSE,path=NULL)
   {
-    cat(paste("Reading file of frequencies ",
-                path.mcmc,
-                "frequencies.txt",sep=""))
                                         # get informations about the MCMC run 
     fileparam <- paste(path.mcmc,"parameters.txt",sep="")
     param <- as.matrix(read.table(fileparam))
@@ -13,17 +11,16 @@ function(path.data,path.mcmc,ipop,iloc,iall,printit=FALSE,path=NULL)
     filef <-  paste(path.mcmc,"frequencies.txt",sep="")
     f <- as.matrix(read.table(filef))
     npopmax <- ncol(f)
-    nall <- scan(paste(path.data,"allele.numbers.txt",sep=""))
-    nloc <- length(nall)
+    nloc <- length(allele.numbers)
                                         # extract frequencies
                                         # from messy matrix f
     sub1 <- rep(FALSE,times=iall-1)
     sub2 <- TRUE
-    sub3 <- rep(FALSE,times=max(nall)-iall)
+    sub3 <- rep(FALSE,times=max(allele.numbers)-iall)
     sub <- c(sub1,sub2,sub3)
-    sub1 <- rep(FALSE,(iloc-1)*max(nall))
+    sub1 <- rep(FALSE,(iloc-1)*max(allele.numbers))
     sub2 <- sub
-    sub3 <- rep(FALSE,(nloc-iloc)*max(nall))
+    sub3 <- rep(FALSE,(nloc-iloc)*max(allele.numbers))
     sub <- rep(c(sub1,sub2,sub3),times=nit/thinning)
     plot(f[sub,ipop],
          xlab=paste("Index of MCMC iteration"," (x ",thinning,")",sep=""),
@@ -36,16 +33,16 @@ function(path.data,path.mcmc,ipop,iloc,iall,printit=FALSE,path=NULL)
     if(printit==TRUE)
       {
         postscript(file=paste(path,"freq.pop",ipop,".loc",iloc,".ps",sep=""))
-        par(mfrow=c(ceiling(sqrt(nall[iloc])),ceiling(sqrt(nall[iloc]))))
+        par(mfrow=c(ceiling(sqrt(allele.numbers[iloc])),ceiling(sqrt(allele.numbers[iloc]))))
                                         # extract frequencies
                                         # in this messy tabular
         sub1 <- rep(FALSE,times=iall-1)
         sub2 <- TRUE
-        sub3 <- rep(FALSE,times=max(nall)-iall)
+        sub3 <- rep(FALSE,times=max(allele.numbers)-iall)
         sub <- c(sub1,sub2,sub3)
-        sub1 <- rep(FALSE,(iloc-1)*max(nall))
+        sub1 <- rep(FALSE,(iloc-1)*max(allele.numbers))
         sub2 <- sub
-        sub3 <- rep(FALSE,(nloc-iloc)*max(nall))
+        sub3 <- rep(FALSE,(nloc-iloc)*max(allele.numbers))
         sub <- rep(c(sub1,sub2,sub3),times=nit/thinning)
         plot(f[sub,ipop],
              xlab=paste("Index of MCMC iteration"," (x ",thinning,")",sep=""),
