@@ -1,17 +1,15 @@
 "PlotFreqA" <-
-function(path.data,path.mcmc,iloc,iall,printit=FALSE,path=NULL)
+function(allele.numbers,path.mcmc,iloc,iall,printit=FALSE,path=NULL)
   {
     fileparam <- paste(path.mcmc,"parameters.txt",sep="/")
     param <- as.matrix(read.table(fileparam))
-    thinning <- as.numeric(param[12,3])
+    thinning <- as.numeric(param[param[,1]=="thinning",3])
 
-     
-    nall <- scan(paste(path.data,"allele.numbers.txt",sep=""))
-    nloc <- length(nall)
+    nloc <- length(allele.numbers)
     filefa <-  paste(path.mcmc,"ancestral.frequencies.txt",sep="")
     fa <- as.matrix(read.table(filefa))
     X11()
-    plot(fa[,(iloc-1)*max(nall)+iall],
+    plot(fa[,(iloc-1)*max(allele.numbers)+iall],
          xlab=paste("Index of MCMC iteration"," (x ",thinning,")",sep=""),
          ylab=paste("Frequency of allele",
            iall,"at locus",iloc),type="l")
@@ -21,7 +19,7 @@ function(path.data,path.mcmc,iloc,iall,printit=FALSE,path=NULL)
     if(printit==T)
       {
         postscript(file=paste(path,"freq.ancestral.pop.loc",iloc,".ps",sep=""))
-        plot(fa[,(iloc-1)*max(nall)+iall],
+        plot(fa[,(iloc-1)*max(allele.numbers)+iall],
              xlab=paste("Index of MCMC iteration"," (x ",thinning,")",sep=""),
              ylab=paste("Frequency of allele",
                iall,"at locus",iloc),type="l")
